0.0.1

* Инициализация проекта

0.0.2

* Включение в MANIFEST.in всех файлов (а не только .py)

0.0.3

* Добавление в вариант форматирования progress3 вывода тега сценария
* Команда формирования html-отчёта на основе junit xml-данных

0.0.4

* Изменение строгой зависимости Django на нестрогую.

0.0.5

* Удаление метода get_testing_projects и не использование настройки TESTING_PROJECTS для фильтрации директорий автотестов

0.0.6

* Доработка механизма перезапуска для выявления ложных падений

0.0.7

* Удаление ограничения на указание значения параметра --rerun-if-failed

0.0.8

* Вывод информации о версии продукта в html-отчёт результатов выполнения автотестов. 

0.0.9

* Указание check_installed_apps False при вызове version_info

0.0.10

* Добавление функций работы с django-cache. Добавление создания отдельной БД при последовательном запуске. Вывод информации об упавших автотестах при выявленных ложных падениям.